#include <stdio.h>
#include <stdlib.h>
#include <frag-opt.h>

int main(int argc, char **argv)
{
	int recursion = 0;
	long depth = 0;
	char *end;
	FRAG *frag;
	frag_option fops[] = {
/*	 id short long          type      arg-name   description          */
	{ 0,      FRAG_PROGRAM,           "[FILES]", "an example program" },
	{ 1, 'h', "help",       0,        NULL,      "print help-message" },
	{ 2, 'v', "version",    0,        NULL,      "print version info" },
	{ 3, 'r', "recursive",  FRAG_NEG, NULL,      "search recursively" },
	{ 4, 'd', "depth",      FRAG_ARG, "DEPTH",   "depth of recursion" },
	{ FRAG_END_ARRAY }
	};

	frag = frag_init(fops, argc, argv, 0);
	if (frag == NULL) {
		printf("out of memory\n");
		exit(EXIT_FAILURE);
	}

	while (frag_parse(frag)) {
		switch (frag->id) {
			case 0:
				printf("arg: %s\n", frag->arg);
				break;
			case 1:
				frag_usage(frag);
				frag_free(frag);
				exit(EXIT_SUCCESS);
			case 2:
				printf("example version 0.99.3\n");
				frag_free(frag);
				exit(EXIT_SUCCESS);
			case 3:
				recursion = frag->type;
				break;
			case 4:
				depth = strtol(frag->arg, &end, 0);
				if (*end != '\0' || depth < 0) {
					fprintf(stderr, "depth must be a positive integer\n");
					frag_free(frag);
					exit(EXIT_FAILURE);
				} else if (depth == 0)
					recursion = 0;
				else
					recursion = 1;
				break;
			default:
				frag_free(frag);
				exit(EXIT_FAILURE);
		}
	}
	frag_free(frag);

	printf("recursion is %s, depth is %li\n", (recursion ? "on": "off"), depth);

	return 0;
}
